==> freemedforms-project_0.7.6.orig.tar.gz: freemedforms-0.7.6/global_resources/translations/xmlioplugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>XmlForms::Internal::XmlFormIO</name>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="140"/>
        <source>Invalid form file detected: %1</source>
        <translation>Fichier formulaire invalide détecté : %1</translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="141"/>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="210"/>
        <source>Invalid file detected.</source>
        <translation>Fichier invalide détecté.</translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="142"/>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="211"/>
        <source>An invalid file was found. Please contact your software administrator.
Wrong file: %1
Error: %2</source>
        <translation>Un fichier invalide a été trouvé. Veuillez contacter votre administrateur logiciel.
Fichier : %1
Erreur : %2</translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="209"/>
        <source>Invalid script file detected: %1</source>
        <translation>Fichier script invalide détecté : %1</translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="326"/>
        <source>No form file name</source>
        <translation>Pas de nom de formulaire</translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="450"/>
        <source>Form: </source>
        <translation>Formulaire : </translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="451"/>
        <source>New version: %1</source>
        <translation>Nouvelle version : %1</translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="452"/>
        <source>Database version: %1</source>
        <translation>Version en base de données : %1</translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="466"/>
        <source>Form update detected.</source>
        <translation>Mise à jour de formulaire détectée.</translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="467"/>
        <source>A form update has been detected. Do you want to update the forms?</source>
        <translation>Une mise à jour de formulaire a été détectée. Voulez-vous mettre à jour les formulaires ?</translation>
    </message>
</context>
<context>
    <name>XmlForms::Internal::XmlIOBase</name>
    <message>
        <location filename="../../plugins/xmlioplugin/xmliobase.cpp" line="723"/>
        <source>Error while saving PMHxCateogries (%1)</source>
        <translation>Erreur lors de la sauvegarde des catégories ATCD (%1)</translation>
    </message>
</context>
<context>
    <name>XmlIOBase</name>
    <message>
        <location filename="../../plugins/xmlioplugin/xmliobase.cpp" line="212"/>
        <source>Trying to create empty database.
       Location: %1
       FileName: %2
       Driver: %3</source>
        <translation></translation>
    </message>
</context>
</TS>

==> freemedforms-project_0.8.0.orig.tar.gz: freemedforms-0.8.0/global_resources/translations/xmlioplugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>XmlForms::Internal::XmlFormIO</name>
    <message>
        <source>Invalid form file detected: %1</source>
        <translation>Fichier formulaire invalide détecté : %1</translation>
    </message>
    <message>
        <source>Invalid file detected.</source>
        <translation>Fichier invalide détecté.</translation>
    </message>
    <message>
        <source>An invalid file was found. Please contact your software administrator.
Wrong file: %1
Error: %2</source>
        <translation>Un fichier invalide a été trouvé. Veuillez contacter votre administrateur logiciel.
Fichier : %1
Erreur : %2</translation>
    </message>
    <message>
        <source>Invalid script file detected: %1</source>
        <translation>Fichier script invalide détecté : %1</translation>
    </message>
    <message>
        <source>No form file name</source>
        <translation>Pas de nom de formulaire</translation>
    </message>
    <message>
        <source>Form: </source>
        <translation>Formulaire : </translation>
    </message>
    <message>
        <source>New version: %1</source>
        <translation>Nouvelle version : %1</translation>
    </message>
    <message>
        <source>Database version: %1</source>
        <translation>Version en base de données : %1</translation>
    </message>
    <message>
        <source>Form update detected.</source>
        <translation>Mise à jour de formulaire détectée.</translation>
    </message>
    <message>
        <source>A form update has been detected. Do you want to update the forms?</source>
        <translation>Une mise à jour de formulaire a été détectée. Voulez-vous mettre à jour les formulaires ?</translation>
    </message>
</context>
<context>
    <name>XmlForms::Internal::XmlIOBase</name>
    <message>
        <source>Error while saving PMHxCateogries (%1)</source>
        <translation>Erreur lors de la sauvegarde des catégories ATCD (%1)</translation>
    </message>
</context>
<context>
    <name>XmlIOBase</name>
    <message>
        <source>Trying to create empty database.
       Location: %1
       FileName: %2
       Driver: %3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
